@@ -79,6 +79,9 @@ class AdsAPIError(Exception):
         self.code = data['error']['code']
         self.type = data['error']['type']
 
+    def __str__(self):
+        return '(%s %s) %s' % (self.type, self.code, self.message)
+
 
 class AdsAPI(object):
     """A client for the Facebook Ads API."""
@@ -712,7 +715,7 @@ class AdsAPI(object):
         args = {
             'name': name,
             'bid_type': bid_type,
-            'bid_info': bid_info,
+            'bid_info': json.dumps(bid_info),
             'campaign_id': campaign_id,
             'creative': json.dumps({'creative_id': creative_id}),
             'targeting': json.dumps(targeting),
